function [WinningTeam, DaysPlayed] = werewolf(Num_Players, PercWerewolf, ...
          varargin)
%% Introduction: Werewolf Game
% function [WinningTeam, DaysPlayed] = Werewolf(Num_Players, PercWerewolf,
%           varargin)
%
% In the game werewolf, two teams play against each other, the villagers 
% and the werewolves. 
% During the night phase the werewolves decide on one villager to kill, 
% while the villagers sleep. The game starts with a night phase.
% During the day phase, the werewolves pretend to be villagers and the 
% entire village decides who should be sentenced to death as a revenge for 
% last night’s victim. A team (villager or werewolves) wins when the last 
% member of the other team is killed.
%
% Input Arguments: 
%
%   NumPlayers    -> Sum of players (wolves and villagers) 
%                    [positive integer]
%
%   Perc_Werewolf -> Share of Werewolf on the Players in percent 
%                    [positive integer < 100]
% 
%   varargin      -> Variable input arguments [char] to activate 
%                    additional players, such as: 
%
%     'Hunter'       -> Unique member of the villagers; kills another  
%                       random player when killed
%
%     'Witch'       -> Unique member of the villagers which is active at 
%                      night; posseses two potions, of which one can kill 
%                      an additional player and the the other one can save   
%                      a villager, and which of course can only be used 
%                      once and as long as the witch is alive
%
%     'PercPotion'  -> Probability that potion is used; 
%                      [positive integer < 100, default = 50]
%
% Output Arguments:
%
%   WinningTeam   -> Name of the winning team
%
%   DaysPlayed    -> Number of days played
%
%
% 15.09.2022

%% Check variables
if ~(rem(Num_Players, 1) == 0) || Num_Players <= 0 || ~isnumeric(Num_Players)
    error('Num_Players must be a positive whole value')
elseif PercWerewolf <= 0 || PercWerewolf >= 100 || ~isnumeric(PercWerewolf)
    error('PercWerewolf muss be a number between 1 & 99')
end

if ~isempty(varargin)
    for z = 1:length(varargin)
        if sum(strcmp(varargin{z}, {'Hunter', 'Witch'})) ~= 1
            warning('%g. input arguments might be unused', (z+2))
        end
    end
end
%% Declaration
Wolves = round(Num_Players*(PercWerewolf/100));    % Number of wolves
Villagers = Num_Players - Wolves;                  % Number of villagers
DaysPlayed = 0;                                    % Number of days played

%% Activation of additional characters

% Input argument 'Hunter' determines hunter as active player
Hunter_mode = 0;
if sum(strcmp(varargin,'Hunter')) > 0
    Hunter_mode = 1;
end

%% Game-Loop
while Villagers > 0 && Wolves > 0           % Game runs as long as both 
                                            % teams have active players
    %% Victim of the night
    Victim_identity = randi([1 Villagers]); % identity of victim                                              
    Villagers = Villagers - 1;              % one villager gets killed
    if sum(Villagers) == 0                  
        %disp('Tonight the last villager has been killed!')
        break                               % break possible
    else
        %disp('There has been a nights victim')
    end
   
    % Hunter-Variation                                           
    if Hunter_mode == 1 && ...                   % additional victim, if
       randi([1 Villagers]) == Victim_identity   % hunter is active                    
        [Wolves, Villagers, Hunter_mode] = ...   % (Hunter_mode = 1) and
            Hunter_funk(Wolves, Villagers);      % aligns with villager
                                                 % victims identity 
        if Wolves <= 0 || Villagers <= 0
           % disp('The Hunter has endet the game during nighttime!')
            break                          % break possible
        end
    end
    %% Victim of the day
    Players = Wolves + Villagers;          % Victim is chosen from all 
                                           % players with equal chance
    Victim_identity = randi([1 Players]);  % Victim identifies through 
    if Victim_identity > Wolves            % random index, first indicies 
        Villagers = Villagers - 1;         % belong to according number of 
                                           % wolves
        %disp('Ironically a Villager got killed at daytime for revenge')
        
        % Hunter Variation
        if Hunter_mode == 1 && randi([Wolves+1 Players]) == Victim_identity
            [Wolves, Villagers, Hunter_mode] = ...
                Hunter_funk(Wolves, Villagers);
        end
    else 
        Wolves = Wolves - 1;
        %disp('A Wolf got killed at daytime for revenge')
    end
    
    %% Day Review
    DaysPlayed = DaysPlayed+1;
   % disp(fprintf('Remaining Players: %g Villagers and %g Werewolves', ...
       % Villagers, Wolves))
end
%% End of Game
if Villagers > 0                        % as loosing Team has zero members, 
    WinningTeam = 'Villagers';          % the other team is declared winner
else
    WinningTeam = 'Wolves';
end

%disp(fprintf('Winning Team: %s', WinningTeam))
%disp(fprintf('Days Played: %g', DaysPlayed))

end
% hihi